// Wraper to call slugtest.m script
//
// Copyright: Evangelos Rozos
// Created: January 2013

// Compile it with Octave using
// mkoctfile --link-stand-alone SlugTest.cc  -o SlugTest.exe

#include <conio.h>
#include <iostream>
#include <octave/oct.h>
#include <octave/octave.h>
#include <octave/parse.h>

int filenotopened(const char* filename)
{
    FILE* fp;

    fp= fopen(filename, "w");

    if (fp==NULL) {
      fprintf(stderr, "%s should be closed!\n", filename);
      return 0;
    }
    else {
      fclose(fp);
      return 1;
    } 
}

int file_exists(const char * filename)
{
    if (FILE * file = fopen(filename, "r"))
    {
        fclose(file);
        return 1;
    }
    return 0;
}

int main (int argc, char *argvc[])
{
  char c;

  string_vector argv (2);
  argv(0) = "SlugTest";
  argv(1) = "-q";

  /* Start engine */
  octave_main (2, argv.c_str_vec(), 1); 

  /* Clear screen */ 
  printf("\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"); 

  while (c!='q' )
  {

    /* Print menu */
    printf("Press <s> for quasi-steady method.\n");
    printf("Press <h> for Hvorlsev.\n");
    printf("Press <b> for Butler.\n");
    printf("Press <p> for plotting quasi-steady curves.\n");
    printf("Press <q> for quit.\n");
    c=getch();

    /* Check that input files exist */
    if (!file_exists("../Measurements.csv") ) {
        fprintf(stderr, "\nWhere is Measurements.csv?\n\n"); continue; }
    if (!file_exists("../constants.txt") ) {
      fprintf(stderr, "\nWhere is constants.txt?\n\n"); continue; }

    /* Run appropriate script */
    if (c=='s' && filenotopened("../Results.csv") && 
                  filenotopened("../K_Ss.txt") ) {
      fprintf(stderr, "Running optimization...\n");
      octave_value_list out = feval ("slugtest");
      fprintf(stderr, "Results were saved in K_Ss.txt and Results.csv\n");
    }
    if (c=='p'&& filenotopened("../Results.csv") ) {
      fprintf(stderr, "Saving values in Results.csv\n");
      octave_value_list out = feval ("plotqscurve");
    }
    if (c=='h') {
      fprintf(stderr, "Hvorslev's estimation is:\n");
      octave_value_list out = feval ("hvorslev");
    } 
    if (c=='b') {
      fprintf(stderr, "Butler's estimation is:\n");
      octave_value_list out = feval ("butler");
    } 
    printf("\n\n");
  }


  return 0;
}
