% Estimation of K using Hvorlsev method and Butler approach
%
%# 
%# This program is free software; you can redistribute it and/or modify
%# it under the terms of the GNU General Public License as published by
%# the Free Software Foundation; either version 3 of the License, or
%# (at your option) any later version.
%# 
%# This program is distributed in the hope that it will be useful,
%# but WITHOUT ANY WARRANTY; without even the implied warranty of
%# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%# GNU General Public License for more details.
%# 
%# You should have received a copy of the GNU General Public License
%# along with Octave; see the file COPYING.  If not, see
%# <http://www.gnu.org/licenses/>.

%# Author: rozos <rozos@itia.ntua.gr>
%# Created: 2013-04-20

% Read configuration file 
configure

% Get problem properties and measurements and share with opt. function
load ../constants.txt
rs=constants(1); rc=constants(2); b=constants(3);
Measurements=dlmread('../Measurements.csv', delimiter);

% Fit a line to points with 0.15<H/H0<0.25
ButlerRange=0.15<Measurements(:,2) & Measurements(:,2)<0.25;
if (sum(ButlerRange)<2)
    b1=find(Measurements (:,2)<.25);
    b2=find(Measurements (:,2)<.15);
    ButlerRange=[ b1(1)-1 b2(1)];
end;
ButObs=[Measurements(ButlerRange,1) Measurements(ButlerRange,2) ]; 
p=polyfit(ButObs(:,1), log(ButObs(:,2)), 1);

% Find time when H/H0=0.368
My=Measurements (:, 2)/exp(p(2)); Mx=Measurements(:,1);
t0=interp1(My(0<My & My<0.7), Mx(0<My & My<0.7), 0.368);
K=rc^2*log(200)/2/b/t0*86400;
fprintf('K=%e m/d\n', K)
