% Objective function. Returns distance between calculated H/Ho curve and
% slugtest measurements
%
% Copyright: Evangelos Rozos
% Created: December 2012

function ret=logobjf(KSs)

global rs rc b Obs;

% Get K, Ss
K=exp(KSs(1)); 
Ss=exp(KSs(2));

% Transform to dimensionless measurements
Xmes=Obs(:,1)*K/86400*b/rc^2;
Ymes=Obs(:,2);

% Penalty to values with no pysical meaning
if ( K<0|| K>100 || Ss<0 || Ss>1   ) 
    ret=1000;
    return;
end;

% Prepare quasis-steady H/Ho curves
[HbHo B]=quasisteadycurves( Ss, rs, b, rc);

% If outside B range then bad parameters
if (min(B)>min(Xmes) || max(Xmes)>max(B)) 
    ret=1000*max(-1/min(B)+1/min(Xmes), max(Xmes)-max(B));
    return;
end;

% Return distance between measurements and curve
Ycrv=interp1(B, HbHo, Xmes);
rms=100*mean((Ymes-Ycrv).^2);
rtdist=0.01*sum(sqrt(abs(Ymes-Ycrv)));
area=abs(sum(Ymes-Ycrv));
absdist=0.1*sum(abs(Ymes-Ycrv));
ret=rtdist+2*absdist+0.1*rms+0.01*area;
