% Script to save quasi-steady curves and measurements to Results.csv
%
% Copyright: Evangelos Rozos
% Created: January 2013

% Read configuration file 
configure

% Load data
load ../constants.txt
rs=constants(1); rc=constants(2); b=constants(3);
Measurements=dlmread('../Measurements.csv', delimiter);
load ../K_Ss.txt

% Print objective function value
fprintf('Objective function= %2.2e\n', logobjf(log(K_Ss)));

% Call quasi-steady method
[HbHo B]= quasisteadycurves( K_Ss(2), rs, b, rc);

% Turn time to dimensionless beta
Measurs= [Measurements(:,1)*K_Ss(1)/86400*b/rc^2, Measurements(:,2)];

% Make measurements and quasi-steady-results equally sized
Blanks= ones(size(HbHo,2)-size(Measurs,1), 2)*1e-10;

% Save results
ForSaving =[[Measurs;Blanks], B', HbHo'];
dlmwrite('../Results.csv', ForSaving, 'delimiter', delimiter);
