% Script to estimate K and Ss using Koussis and Akylas method.
%
% Copyright: Evangelos Rozos
% Created: January 2013

% Read configuration file 
configure

% Get problem properties and measurements and share with opt. function
global rs rc b Obs;
load ../constants.txt
rs=constants(1); rc=constants(2); b=constants(3);
Measurements=dlmread('../Measurements.csv', delimiter);

% Optimize using only the measurements with H/Ho>0.33
KoussisRange=and(Measurements(:,2)>0.33, Measurements(:,2)<0.98);
Obs=[Measurements(KoussisRange,1) Measurements(KoussisRange,2)];
[logbestKSs1 bestf1]=sceua(@logobjf, log([0.1 0.001]), [-20 -26], [6 0], 10000, 5, 0.01, 0.01, 3, -1, 1);
[logbestKSs2 bestf2]=sceua(@logobjf, log([0.1 0.001]), [-20 -26], [6 0], 10000, 5, 0.01, 0.01, 4, -1, 1);
logbestKSs=logbestKSs1; if (bestf1>bestf2); logbestKSs=logbestKSs2; end

% Print and save parameters
fprintf('K=%e m/d\n', exp(logbestKSs(1)));
fprintf('Ss=%e 1/m\n', exp(logbestKSs(2)));
[fid MSG]=fopen('../K_Ss.txt','w');
if (fid==-1); error(MSG); end 
fprintf(fid, '%% K (m/d)\r\n%e\r\n', exp(logbestKSs(1)));
fprintf(fid, '%% Ss (1/m)\r\n%e\r\n', exp(logbestKSs(2)));
fclose(fid); 

% Save curves
[HbHo B]= quasisteadycurves( exp(logbestKSs(2)), rs, b, rc);
Measurs= [Measurements(:,1)*exp(logbestKSs(1))/86400*b/rc^2, Measurements(:,2)];
Blanks= ones(size(HbHo,2)-size(Measurs,1), 2)*1e-10;
ForSaving =[[Measurs;Blanks], B', HbHo'];
dlmwrite('../Results.csv', ForSaving, 'delimiter', delimiter);
